@@ -81,13 +81,14 @@ def get_repo_definition_4_trunk_only_repo_w_tags(
     only official releases.
     """
 
-    def _get_repo_from_defintion(
+    def _get_repo_from_definition(
         commit_type: CommitConvention,
         hvcs_client_name: str = "github",
         hvcs_domain: str = EXAMPLE_HVCS_DOMAIN,
         tag_format_str: str | None = None,
         extra_configs: dict[str, TomlSerializableTypes] | None = None,
-        mask_initial_release: bool = False,
+        mask_initial_release: bool = True,
+        ignore_merge_commits: bool = True,
     ) -> Sequence[RepoActions]:
         stable_now_datetime = stable_now_date()
         commit_timestamp_gen = (
@@ -95,7 +96,7 @@ def get_repo_definition_4_trunk_only_repo_w_tags(
             for i in count(step=1)
         )
 
-        changelog_file_definitons: Sequence[RepoActionWriteChangelogsDestFile] = [
+        changelog_file_definitions: Sequence[RepoActionWriteChangelogsDestFile] = [
             {
                 "path": changelog_md_file,
                 "format": ChangelogOutputFormat.MARKDOWN,
@@ -141,7 +142,7 @@ def get_repo_definition_4_trunk_only_repo_w_tags(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
-                                    "angular": INITIAL_COMMIT_MESSAGE,
+                                    "conventional": INITIAL_COMMIT_MESSAGE,
                                     "emoji": INITIAL_COMMIT_MESSAGE,
                                     "scipy": INITIAL_COMMIT_MESSAGE,
                                     "datetime": next(commit_timestamp_gen),
@@ -150,7 +151,7 @@ def get_repo_definition_4_trunk_only_repo_w_tags(
                                     ),
                                 },
                                 {
-                                    "angular": "feat: add new feature",
+                                    "conventional": "feat: add new feature",
                                     "emoji": ":sparkles: add new feature",
                                     "scipy": "ENH: add new feature",
                                     "datetime": next(commit_timestamp_gen),
@@ -171,7 +172,7 @@ def get_repo_definition_4_trunk_only_repo_w_tags(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -190,9 +191,9 @@ def get_repo_definition_4_trunk_only_repo_w_tags(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
-                                    "angular": "fix: correct some text",
-                                    "emoji": ":bug: correct some text",
-                                    "scipy": "MAINT: correct some text",
+                                    "conventional": "fix: correct some text\n\nResolves: #123\n",
+                                    "emoji": ":bug: correct some text\n\nResolves: #123\n",
+                                    "scipy": "MAINT: correct some text\n\nResolves: #123\n",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
@@ -211,7 +212,7 @@ def get_repo_definition_4_trunk_only_repo_w_tags(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -222,7 +223,7 @@ def get_repo_definition_4_trunk_only_repo_w_tags(
 
         return repo_construction_steps
 
-    return _get_repo_from_defintion
+    return _get_repo_from_definition
 
 
 @pytest.fixture(scope="session")
@@ -263,7 +264,7 @@ def build_trunk_only_repo_w_tags(
 
 
 @pytest.fixture
-def repo_w_trunk_only_angular_commits_using_tag_format(
+def repo_w_trunk_only_conventional_commits_using_tag_format(
     build_repo_from_definition: BuildRepoFromDefinitionFn,
     get_repo_definition_4_trunk_only_repo_w_tags: GetRepoDefinitionFn,
     get_cached_repo_data: GetCachedRepoDataFn,
@@ -273,7 +274,7 @@ def repo_w_trunk_only_angular_commits_using_tag_format(
     example_project_dir: ExProjectDir,
     change_to_ex_proj_dir: None,
 ) -> BuiltRepoResult:
-    repo_name = repo_w_trunk_only_angular_commits_using_tag_format.__name__
+    repo_name = repo_w_trunk_only_conventional_commits_using_tag_format.__name__
     commit_type: CommitConvention = (
         repo_name.split("_commits", maxsplit=1)[0].split("_")[-1]  # type: ignore[assignment]
     )
@@ -302,13 +303,13 @@ def repo_w_trunk_only_angular_commits_using_tag_format(
 
 
 @pytest.fixture
-def repo_w_trunk_only_angular_commits(
+def repo_w_trunk_only_conventional_commits(
     build_trunk_only_repo_w_tags: BuildSpecificRepoFn,
     example_project_git_repo: ExProjectGitRepoFn,
     example_project_dir: ExProjectDir,
     change_to_ex_proj_dir: None,
 ) -> BuiltRepoResult:
-    repo_name = repo_w_trunk_only_angular_commits.__name__
+    repo_name = repo_w_trunk_only_conventional_commits.__name__
     commit_type: CommitConvention = repo_name.split("_")[-2]  # type: ignore[assignment]
 
     return {
